(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    182547,       5216]
NotebookOptionsPosition[    167781,       4985]
NotebookOutlinePosition[    168395,       5008]
CellTagsIndexPosition[    168352,       5005]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"268cac08-3ca0-4a0b-abd5-463465f5e3c7"],

Cell["Chapter 6, Section 6.5", "Section",ExpressionUUID->"577fd798-653f-4a35-8939-48e844b36cf6"],

Cell[TextData[{
 "We are going to derive an expansion of the planetary disturbing function \
complete to second order in the the eccentricities and inclinations.\n\nWe \
start by defining a function, ",
 StyleBox["Truncate", "Input"],
 ", that will truncate series in the eccentricities and inclinations to a \
specified order."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"977a8fa1-c91b-4c38-ae3e-967ab3028233"],

Cell["\<\
Truncate[expr_, n_Integer]:=
Module[{},Normal[Series[
(TrigReduce[expr] /. \
{e\[Rule]e*p,e'\[Rule]e'*p,s\[Rule]s*p,s'\[Rule]s'*p}),{p,0,n}]] /. p\[Rule]1]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"f62bc1f8-aefc-4adb-9267-62d9e50800f8"],

Cell[TextData[{
 "Next we use Eq.(2.84) to derive a series for Sin[",
 StyleBox["f",
  FontSlant->"Italic"],
 "] where f is the true anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c9d90c32-eaae-4c7e-add1-e055739650ce"],

Cell[CellGroupData[{

Cell["\<\
sf=
Collect[Series[TrigReduce[
2*Series[Sqrt[1-e^2],{e,0,2}]*Sum[(1/i)*
D[Normal[Series[BesselJ[i,i*e],{e,0,3}]]*
Sin[i*M],e],{i,3}]],{e,0,2}],e]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"a677e534-7836-4fc2-944c-dfc5fd987d59"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", "M", "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "7"}], " ", 
      RowBox[{"Sin", "[", "M", "]"}]}], "+", 
     RowBox[{"9", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323831082182*^9, 3.890974353564891*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"98784b29-267a-4b26-960c-76246819e6f2"]
}, Open  ]],

Cell[TextData[{
 "We can remove some of the brackets by collecting the terms in ",
 StyleBox["e",
  FontSlant->"Italic"],
 ".  This gives Eq.(6.73)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b3eb6b3e-3e99-40fa-a481-c9b6ca135bb6"],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e]", "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"5754e5fd-9111-420a-ad4c-b5f05020ed1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", "M", "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"7", " ", 
        RowBox[{"Sin", "[", "M", "]"}]}], "8"]}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8113238310868464`*^9, 3.890974353570725*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"3fe99f9c-1176-4b0c-a017-eccf07bb6825"]
}, Open  ]],

Cell[TextData[{
 "Now we do a similar series for Cos[",
 StyleBox["f",
  FontSlant->"Italic"],
 "] using Eq.(2.85)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ac8537ed-97ad-44ac-bdec-022c311d3934"],

Cell[CellGroupData[{

Cell["\<\
cf=
Collect[Series[TrigReduce[
-e+(2*(1-e^2)/e)*Sum[
Normal[Series[BesselJ[i,i*e],{e,0,3}]]*
Cos[i*M],{i,3}]],{e,0,2}],e]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"ff7854cf-b953-470f-821e-d148f793270a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", "M", "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "M"}], "]"}]}], ")"}]}], "-", 
  RowBox[{
   FractionBox["9", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "M", "]"}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", "M"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323831133789*^9, 3.890974353592168*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"ebfe3eb6-9408-42fb-b195-6c88aeafa011"]
}, Open  ]],

Cell[TextData[{
 "We can remove some of the brackets by collecting the terms in ",
 StyleBox["e",
  FontSlant->"Italic"],
 ".  This gives Eq.(6.74)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"626cffce-a6e4-4de1-bc46-040ba6ffd55f"],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e]", "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"24d75f50-ebd6-4d28-ad47-341b56794b16"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", "M", "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "M"}], "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"9", " ", 
        RowBox[{"Cos", "[", "M", "]"}]}], "8"]}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8113238311385307`*^9, 3.890974353602642*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"52591f76-e150-4f7e-88b4-e62ddd681291"]
}, Open  ]],

Cell[TextData[{
 "Create similar series for Cos[",
 StyleBox["f'",
  FontSlant->"Italic"],
 "] and Sin[",
 StyleBox["f'",
  FontSlant->"Italic"],
 "] by substitution."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fb4bbca1-f3f9-46c8-8065-25628f6ab695"],

Cell["cfp=cf/.{M->M', e->e'};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"012207de-bb62-4072-8bfc-71c191b394f8"],

Cell["sfp=sf/.{M->M', e->e'};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"76740d3a-2c83-4d1d-b974-d322548a2c70"],

Cell[TextData[{
 "Now we can derive the series for Cos[\[Omega]+",
 StyleBox["f",
  FontSlant->"Italic"],
 "], ",
 "Cos[\[Omega]'+",
 StyleBox["f'",
  FontSlant->"Italic"],
 "], Sin[",
 "\[Omega]+",
 StyleBox["f",
  FontSlant->"Italic"],
 "] and Sin[",
 "\[Omega]'+",
 StyleBox["f'",
  FontSlant->"Italic"],
 "].  See Eqs.(6.75) and (6.76)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ff5d6f2d-6f7b-4af7-8bb7-bc88f1195034"],

Cell[CellGroupData[{

Cell["cfom=Collect[TrigReduce[cf*Cos[\[Omega]]-sf*Sin[\[Omega]]],e]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"5215fb4d-5f52-434f-b2d3-f08654290073"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"M", "+", "\[Omega]"}], "]"}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", "e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"Cos", "[", "\[Omega]", "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "M"}], "+", "\[Omega]"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"M", "-", "\[Omega]"}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"M", "+", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"9", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"3", " ", "M"}], "+", "\[Omega]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323831192092*^9, 3.890974353629208*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"370b92e1-c126-40a6-824b-b32cd5acefc7"]
}, Open  ]],

Cell["cfomp=cfp*Cos[\[Omega]']-sfp*Sin[\[Omega]'];", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"5a218f99-cc40-416a-96bb-8eac8b47a6b3"],

Cell[CellGroupData[{

Cell["sfom=Collect[TrigReduce[sf*Cos[\[Omega]]+cf*Sin[\[Omega]]],e]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"6d40ce15-76e1-4123-8dac-256335df00bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{"M", "+", "\[Omega]"}], "]"}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", "e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"Sin", "[", "\[Omega]", "]"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"2", " ", "M"}], "+", "\[Omega]"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"M", "-", "\[Omega]"}], "]"}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"M", "+", "\[Omega]"}], "]"}]}], "+", 
     RowBox[{"9", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"3", " ", "M"}], "+", "\[Omega]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8113238312405567`*^9, 3.890974353650963*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"30d55bbe-e643-4614-b64c-defd74ff600d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e]", "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"3fc990f7-73e2-46b0-a405-0710aff369bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{"M", "+", "\[Omega]"}], "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", "\[Omega]", "]"}]}], "+", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", "\[Omega]"}], "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"M", "-", "\[Omega]"}], "]"}]}], "-", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "+", "\[Omega]"}], "]"}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"3", " ", "M"}], "+", "\[Omega]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323831286167*^9, 3.890974353667323*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"41149c03-d5d3-46f2-83a0-77d81e1b7629"]
}, Open  ]],

Cell["sfomp=sfp*Cos[\[Omega]']+cfp*Sin[\[Omega]'];", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"14c910b9-02ad-4fc1-9454-69bb0fd0ae25"],

Cell[TextData[{
 "Define Cos[",
 StyleBox["I",
  FontSlant->"Italic"],
 "] and Sin[",
 StyleBox["I",
  FontSlant->"Italic"],
 "] in terms of ",
 StyleBox["s", "Input"],
 " = Sin[",
 StyleBox["I",
  FontSlant->"Italic"],
 "/2]."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ae292da0-7984-4925-b141-782653f3a7fd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ci", "=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"s", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"si", "=", 
   RowBox[{"2", "s"}]}], ";"}]}], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"eeefe81d-aba8-4b60-8137-a63d7d65b076"],

Cell[TextData[{
 "Now we can calculate series for ",
 StyleBox["x/r",
  FontSlant->"Italic"],
 " (see Eq.(6.79)) ..."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"356a18af-bc1e-4812-a8ea-b373fc49bcb2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xor", "=", "\[IndentingNewLine]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Truncate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "\[CapitalOmega]", "]"}], "*", "cfom"}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", "\[CapitalOmega]", "]"}], "*", "sfom", "*", 
        "ci"}]}], ",", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"e", ",", "s"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[15]:=",ExpressionUUID->"d2a41ff3-7c4d-44bd-9eee-f6ed8e120799"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"M", "+", "\[Omega]", "-", "\[CapitalOmega]"}], "]"}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"M", "+", "\[Omega]", "+", "\[CapitalOmega]"}], "]"}]}], 
    ")"}]}], "+", 
  RowBox[{"Cos", "[", 
   RowBox[{"M", "+", "\[Omega]", "+", "\[CapitalOmega]"}], "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Omega]", "+", "\[CapitalOmega]"}], "]"}]}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", "\[Omega]", "+", "\[CapitalOmega]"}], 
      "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "8"]}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"M", "-", "\[Omega]", "-", "\[CapitalOmega]"}], "]"}]}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"M", "+", "\[Omega]", "+", "\[CapitalOmega]"}], "]"}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"3", " ", "M"}], "+", "\[Omega]", "+", "\[CapitalOmega]"}], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323831879857*^9, 3.8909743537222347`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"0c1e9c21-659a-4175-9bdf-fd1984beb71b"]
}, Open  ]],

Cell[TextData[{
 "... and ",
 StyleBox["y/r",
  FontSlant->"Italic"],
 " (see Eq.(6.80)) ..."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d2e7f5ee-0410-4a15-87e6-ea58a23cb951"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yor", "=", "\[IndentingNewLine]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Truncate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "\[CapitalOmega]", "]"}], "*", "cfom"}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "\[CapitalOmega]", "]"}], "*", "sfom", "*", 
        "ci"}]}], ",", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"e", ",", "s"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"b278f798-0b27-494a-bc10-96cfe5da416c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       RowBox[{"M", "+", "\[Omega]", "-", "\[CapitalOmega]"}], "]"}]}], "-", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "+", "\[Omega]", "+", "\[CapitalOmega]"}], "]"}]}], 
    ")"}]}], "+", 
  RowBox[{"Sin", "[", 
   RowBox[{"M", "+", "\[Omega]", "+", "\[CapitalOmega]"}], "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Omega]", "+", "\[CapitalOmega]"}], "]"}]}], "+", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", "\[Omega]", "+", "\[CapitalOmega]"}], 
      "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"M", "-", "\[Omega]", "-", "\[CapitalOmega]"}], "]"}]}], "-", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "+", "\[Omega]", "+", "\[CapitalOmega]"}], "]"}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"3", " ", "M"}], "+", "\[Omega]", "+", "\[CapitalOmega]"}], 
       "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323831935608*^9, 3.890974353769258*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"12d2cec3-32be-45ed-88a6-a12b5000aa0d"]
}, Open  ]],

Cell["... and z/r (see Eq.(6.81)).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8f8b3f99-284d-4dac-897e-4d6cdd030069"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zor", "=", "\[IndentingNewLine]", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Truncate", "[", 
     RowBox[{
      RowBox[{"sfom", "*", "si"}], ",", "2"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"e", ",", "s"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"3143bde6-6c63-405b-8bee-c8ba00932f78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"M", "+", "\[Omega]"}], "]"}]}], "+", 
  RowBox[{"e", " ", "s", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"Sin", "[", "\[Omega]", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"2", " ", "M"}], "+", "\[Omega]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8113238319852533`*^9, 3.8909743537870502`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"4b068232-5ee9-4059-9380-cd3f6b3be37a"]
}, Open  ]],

Cell[TextData[{
 "There are similar series for ",
 StyleBox["x'/r'",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y'/r'",
  FontSlant->"Italic"],
 " and",
 StyleBox[" z'/r'",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"28480724-eb2a-4fdc-a598-0fa5f2b655a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xorp", "=", 
   RowBox[{"xor", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"e", "\[Rule]", 
       RowBox[{"e", "'"}]}], ",", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"s", "'"}]}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", 
       RowBox[{"\[Omega]", "'"}]}], ",", 
      RowBox[{"\[CapitalOmega]", "\[Rule]", 
       RowBox[{"\[CapitalOmega]", "'"}]}], ",", 
      RowBox[{"M", "\[Rule]", 
       RowBox[{"M", "'"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellLabel->"In[18]:=",ExpressionUUID->"8005ec93-998c-42ec-977b-3edb923f1df0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"yorp", "=", 
   RowBox[{"yor", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"e", "\[Rule]", 
       RowBox[{"e", "'"}]}], ",", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"s", "'"}]}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", 
       RowBox[{"\[Omega]", "'"}]}], ",", 
      RowBox[{"\[CapitalOmega]", "\[Rule]", 
       RowBox[{"\[CapitalOmega]", "'"}]}], ",", 
      RowBox[{"M", "\[Rule]", 
       RowBox[{"M", "'"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellLabel->"In[19]:=",ExpressionUUID->"aff55732-11ec-4325-99ea-8c02b131dede"],

Cell[BoxData[
 RowBox[{
  RowBox[{"zorp", "=", 
   RowBox[{"zor", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"e", "\[Rule]", 
       RowBox[{"e", "'"}]}], ",", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"s", "'"}]}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", 
       RowBox[{"\[Omega]", "'"}]}], ",", 
      RowBox[{"\[CapitalOmega]", "\[Rule]", 
       RowBox[{"\[CapitalOmega]", "'"}]}], ",", 
      RowBox[{"M", "\[Rule]", 
       RowBox[{"M", "'"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellLabel->"In[20]:=",ExpressionUUID->"53a59654-c56c-4a32-bb45-d8819f15aafa"],

Cell["\<\
This allows us to calculate the series for Cos[\[Psi]] (see Eq.(6.82)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"41f17a8f-ae14-40e3-9f7e-4777ea545792"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cpsi", "=", 
  RowBox[{"TrigReduce", "[", 
   RowBox[{
    RowBox[{"Truncate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xor", "*", "xorp"}], "+", 
       RowBox[{"yor", "*", "yorp"}], "+", 
       RowBox[{"zor", "*", "zorp"}]}], ",", "2"}], "]"}], " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"M", "\[Rule]", 
       RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}]}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", 
       RowBox[{"\[CurlyPi]", "-", "\[CapitalOmega]"}]}], ",", 
      RowBox[{
       RowBox[{"M", "'"}], "\[Rule]", 
       RowBox[{
        RowBox[{"\[Lambda]", "'"}], "-", 
        RowBox[{"\[CurlyPi]", "'"}]}]}], ",", 
      RowBox[{
       RowBox[{"\[Omega]", "'"}], "\[Rule]", 
       RowBox[{
        RowBox[{"\[CurlyPi]", "'"}], "-", 
        RowBox[{"\[CapitalOmega]", "'"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[21]:=",ExpressionUUID->"0d648b35-5eec-4dd5-abd0-bfbcc88199f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"\[Lambda]", "-", 
    SuperscriptBox["\[Lambda]", "\[Prime]",
     MultilineFunction->None]}], "]"}], "-", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["9", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"3", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPi]", "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPi]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["9", "8"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323832418545*^9, 3.890974354023567*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"aadb0f41-88c5-4905-8cfe-414bfd350e57"]
}, Open  ]],

Cell["\<\
We can gather up the terms in the eccentricities and inclinations for easier \
comparison.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cb171c94-3a59-4560-b0c0-f8353607f080"],

Cell[CellGroupData[{

Cell["Collect[Expand[%],{e,e',s,s'}]", "Input",
 CellLabel->"In[22]:=",ExpressionUUID->"1b7d8f61-a6b2-45ba-aab6-de9af2f6115b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"\[Lambda]", "-", 
    SuperscriptBox["\[Lambda]", "\[Prime]",
     MultilineFunction->None]}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}]}], ")"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[CurlyPi]", "-", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
           SuperscriptBox["\[CurlyPi]", "\[Prime]",
            MultilineFunction->None]}], "]"}]}], "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[CurlyPi]", "-", 
          SuperscriptBox["\[CurlyPi]", "\[Prime]",
           MultilineFunction->None]}], "]"}], "+", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Lambda]", "\[Prime]",
            MultilineFunction->None]}], "+", 
          SuperscriptBox["\[CurlyPi]", "\[Prime]",
           MultilineFunction->None]}], "]"}], "-", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[CurlyPi]", "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Lambda]", "\[Prime]",
            MultilineFunction->None]}], "+", 
          SuperscriptBox["\[CurlyPi]", "\[Prime]",
           MultilineFunction->None]}], "]"}]}], ")"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}]}], ")"}]}], "+", 
  RowBox[{"s", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "+", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "+", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323832926516*^9, 3.89097435403369*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"70a14408-f066-4338-9682-6dce50bc4044"]
}, Open  ]],

Cell[TextData[{
 "Because \[Theta] = \[Omega] + \[CapitalOmega] + ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  we can now find the series for Cos[\[Theta] \[Dash] \[Theta]'] (see \
Eq.(6.83))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5a770892-14df-4b80-8063-90f534c6d2ed"],

Cell["\<\
cdtheta=
TrigReduce[Truncate[
(Cos[\[CapitalOmega]]*cfom-Sin[\[CapitalOmega]]*sfom)*(Cos[\[CapitalOmega]']*\
cfomp-Sin[\[CapitalOmega]']*sfomp)+
(Sin[\[CapitalOmega]]*cfom+Cos[\[CapitalOmega]]*sfom)*(Sin[\[CapitalOmega]']*\
cfomp+Cos[\[CapitalOmega]']*sfomp),
2] /. {M\[Rule]\[Lambda]-\[CurlyPi],\[Omega]\[Rule]\[CurlyPi]-\[CapitalOmega],\
M'\[Rule]\[Lambda]'-\[CurlyPi]',\[Omega]'\[Rule]\[CurlyPi]'-\[CapitalOmega]'}]\
;\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[23]:=",ExpressionUUID->"ee6e06a7-2f28-45ce-be47-3af8c8d59dd4"],

Cell["\<\
The quantity \[CapitalPsi] is defined to be the difference between \
Cos[\[Psi]] and Cos[\[Theta] \[Dash] \[Theta]'] (see Eq.(6.84)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bf5ff0df-1bbc-4872-82a0-1fb42f6f1867"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPsi]", "=", 
  RowBox[{"TrigReduce", "[", 
   RowBox[{"cpsi", "-", "cdtheta"}], "]"}]}]], "Input",
 CellLabel->"In[24]:=",ExpressionUUID->"4c0fe377-b9da-4d37-81a1-06ab1b60449d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["s", "2"]}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323832986994*^9, 3.8909743540606213`*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"0ccc12cd-95db-4641-9559-b84d54fa2c63"]
}, Open  ]],

Cell[TextData[{
 "Because this is already second order in the inclinations we can ignore the \
product (",
 StyleBox["r/a",
  FontSlant->"Italic"],
 ")(",
 StyleBox["r'/a'",
  FontSlant->"Italic"],
 ") and write (see Eq.(6.85)):"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ceb1e302-fe67-45a2-a0e8-a3d985e99a8e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rapsi2", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"\[CapitalPsi]", "/", "2"}], "]"}]}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"533a25db-f3a7-427e-bab8-35cc0b4f712d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323833037923*^9, 3.8909743540804157`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"d5d4726a-f01c-4a34-b112-94fa01fdbcf2"]
}, Open  ]],

Cell[TextData[{
 "Now we need to introduce a series for the equation of centre (",
 StyleBox["f",
  FontSlant->"Italic"],
 "\[Dash]",
 StyleBox["M",
  FontSlant->"Italic"],
 ").  We start by deriving a series for the eccentric anomaly in terms of the \
mean anomaly.  (See Eq.(2.80).)"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7e9cd7f6-ad7c-4bec-8298-08860d88fae7"],

Cell[CellGroupData[{

Cell["\<\
ea=Collect[
    M+Expand[
      2*Normal[
       Series[
        Sum[(1/s)BesselJ[s, s e] Sin[s M],{s,1,5}],
       {e,0,5}]]], e]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[26]:=",ExpressionUUID->"0b616fb9-f808-42ee-bc88-e7a4f401444f"],

Cell[BoxData[
 RowBox[{"M", "+", 
  RowBox[{"e", " ", 
   RowBox[{"Sin", "[", "M", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "M", "]"}], "8"]}], "+", 
     RowBox[{
      FractionBox["3", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "6"]}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"4", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"Sin", "[", "M", "]"}], "192"], "-", 
     RowBox[{
      FractionBox["27", "128"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["125", "384"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"5", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323833138054*^9, 3.890974354098721*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"7ae383b1-488d-4c19-9903-b24c0eb04838"]
}, Open  ]],

Cell[TextData[{
 "Now we need the series for \[DifferentialD] ",
 StyleBox["f",
  FontSlant->"Italic"],
 "  (see Eq.(2.87))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7e2b9cf9-8a9b-4d00-b8d8-bc04fec96542"],

Cell["\<\
df=
Collect[TrigReduce[
Normal[Series[Sqrt[1-e^2]*(D[ea, M])^2, {e,0,5}]]],e];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[27]:=",ExpressionUUID->"6495a172-97b8-4e25-b412-bbfe0085836b"],

Cell[TextData[{
 "We integrate this term by term to get the series for ",
 StyleBox["f",
  FontSlant->"Italic"],
 " in terms of ",
 StyleBox["M ",
  FontSlant->"Italic"],
 "(see Eq.(2.88))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b2b87128-93c2-4034-a19d-e902f2289b3e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"Truncate", "[", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{"df", ",", "M"}], "]"}], ",", "e"}], "]"}], ",", "2"}], 
   "]"}]}]], "Input",
 CellLabel->"In[28]:=",ExpressionUUID->"7dd33d17-123e-4ab7-9f27-6e3a77852b3d"],

Cell[BoxData[
 RowBox[{"M", "+", 
  RowBox[{"2", " ", "e", " ", 
   RowBox[{"Sin", "[", "M", "]"}]}], "+", 
  RowBox[{
   FractionBox["5", "4"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.8113238333316383`*^9, 3.8909743543250647`*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"1d73e94c-1500-4ff0-ad4b-8ca8989a6f2e"]
}, Open  ]],

Cell["Express \[Theta] in terms of longitudes ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b47efd75-3e86-4df0-af8d-ecc455c98443"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Theta]", "=", 
  RowBox[{
   RowBox[{"\[Omega]", "+", "\[CapitalOmega]", "+", "f"}], " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"M", "\[Rule]", 
      RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}]}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"\[CurlyPi]", "-", "\[CapitalOmega]"}]}], ",", 
     RowBox[{
      RowBox[{"M", "'"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[Lambda]", "'"}], "-", 
       RowBox[{"\[CurlyPi]", "'"}]}]}], ",", 
     RowBox[{
      RowBox[{"\[Omega]", "'"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CurlyPi]", "'"}], "-", 
       RowBox[{"\[CapitalOmega]", "'"}]}]}]}], "}"}]}]}]], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"6f5ef7c1-6089-4c90-a28a-03ac74b66ad6"],

Cell[BoxData[
 RowBox[{"\[Lambda]", "+", 
  RowBox[{"2", " ", "e", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["5", "4"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], ")"}]}], "]"}]}]}]], "Output",\

 CellChangeTimes->{3.811323833336973*^9, 3.8909743543328257`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"c4e080bf-d185-4040-abe1-22007be1edfb"]
}, Open  ]],

Cell[TextData[{
 "... and derive a series for Cos[",
 StyleBox["j",
  FontSlant->"Italic"],
 "\[Theta]] ..."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8bbf8057-5d5a-464b-b093-7a16ba7b2f11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cjth", "=", 
  RowBox[{"TrigReduce", "[", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"j", "*", "\[Theta]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"e", ",", "0", ",", "2"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"8434f3ac-d5c3-498f-afaa-15ea71e381b3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"j", " ", "\[Lambda]"}], "]"}]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["e", "2"], " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"j", " ", "\[Lambda]"}], "]"}]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["e", "2"], " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "-", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["e", "2"], " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "-", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["e", "2"], " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "+", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["e", "2"], " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "+", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "-", 
    RowBox[{"8", " ", "e", " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}], "+", 
    RowBox[{"8", " ", "e", " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.811323833390257*^9, 3.890974354354314*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"68942aa9-5883-4f0e-99e7-ea86ebbe2f42"]
}, Open  ]],

Cell[" ... tidying up the terms (see Eq.(6.88)).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d0322ef1-2d6f-4594-a398-574802936545"],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e]", "Input",
 CellLabel->"In[31]:=",ExpressionUUID->"06a7b71c-e641-44a6-91bd-cedaef77b8a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"j", " ", "\[Lambda]"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["j", "2"]}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"j", " ", "\[Lambda]"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "j"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}], "+", 
     RowBox[{"j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323833397182*^9, 3.8909743543621473`*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"b9081d0b-62a0-4ab7-b378-11b48fe01c29"]
}, Open  ]],

Cell[TextData[{
 "Similarly, derive a series for Sin[",
 StyleBox["j",
  FontSlant->"Italic"],
 "\[Theta]] and tidy it up (see Eq.(6.89))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"53a03c90-7dd0-4027-a746-e5f6495dc747"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sjth", "=", 
  RowBox[{"TrigReduce", "[", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"j", "*", "\[Theta]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"e", ",", "0", ",", "2"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellLabel->"In[32]:=",ExpressionUUID->"bcbfd89e-e400-404a-9746-1689c3f6398c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"j", " ", "\[Lambda]"}], "]"}]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["e", "2"], " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"j", " ", "\[Lambda]"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["e", "2"], " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "-", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["e", "2"], " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "-", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["e", "2"], " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "+", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["e", "2"], " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Lambda]"}], "+", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", 
       RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
    RowBox[{"8", " ", "e", " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}], "+", 
    RowBox[{"8", " ", "e", " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.8113238334480658`*^9, 3.890974354379722*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"da331f73-5b85-42ae-b182-ac152a485ef7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e]", "Input",
 CellLabel->"In[33]:=",ExpressionUUID->"76786cea-eff7-4360-a50b-42669a6a1c24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{"j", " ", "\[Lambda]"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["j", "2"]}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"j", " ", "\[Lambda]"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}]}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"j", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}], "+", 
     RowBox[{"j", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8113238334539633`*^9, 3.890974354398178*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"a3032a31-618f-4cf2-85c2-658d5322b843"]
}, Open  ]],

Cell[TextData[{
 "Derive the series for Cos[",
 StyleBox["j",
  FontSlant->"Italic"],
 "\[Theta]'] by substitution."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f5ac6518-87f5-42f1-bec6-11ab85058858"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cjthp", "=", 
  RowBox[{"cjth", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e", "\[Rule]", 
      RowBox[{"e", "'"}]}], ",", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"s", "'"}]}], ",", 
     RowBox[{"\[CurlyPi]", "\[Rule]", 
      RowBox[{"\[CurlyPi]", "'"}]}], ",", 
     RowBox[{"\[CapitalOmega]", "\[Rule]", 
      RowBox[{"\[CapitalOmega]", "'"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"\[Lambda]", "'"}]}]}], "}"}]}]}]], "Input",
 CellLabel->"In[34]:=",ExpressionUUID->"ce84ea48-b854-45ab-8766-43361e3c2bae"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"j", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}]}], "-", 
    RowBox[{"8", " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None], "-", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None]}], "+", 
    RowBox[{"8", " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None], "+", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"j", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "-", 
    RowBox[{"5", " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "+", 
    RowBox[{"5", " ", "j", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.811323833460375*^9, 3.890974354407774*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"b54be3f6-e081-4766-8949-dbcc0560c8c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collect[Expand[%],{e,e'}]", "Input",
 CellLabel->"In[35]:=",ExpressionUUID->"b9532fd9-78e7-4dde-a507-d6960c7242d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"j", " ", 
    SuperscriptBox["\[Lambda]", "\[Prime]",
     MultilineFunction->None]}], "]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "j"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["j", "2"]}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323833509877*^9, 3.890974354425729*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"c05435eb-fd56-42d4-8158-9bb3b9c9502c"]
}, Open  ]],

Cell[TextData[{
 "Derive the series for Sin[",
 StyleBox["j",
  FontSlant->"Italic"],
 "\[Theta]'] by substitution."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"998827ba-7f74-4cd7-9195-b641b2228e90"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sjthp", "=", 
  RowBox[{"sjth", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e", "\[Rule]", 
      RowBox[{"e", "'"}]}], ",", 
     RowBox[{"s", "\[Rule]", 
      RowBox[{"s", "'"}]}], ",", 
     RowBox[{"\[CurlyPi]", "\[Rule]", 
      RowBox[{"\[CurlyPi]", "'"}]}], ",", 
     RowBox[{"\[CapitalOmega]", "\[Rule]", 
      RowBox[{"\[CapitalOmega]", "'"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"\[Lambda]", "'"}]}]}], "}"}]}]}]], "Input",
 CellLabel->"In[36]:=",ExpressionUUID->"74991f30-b8d7-4ffd-bf34-d5ee39e05362"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"j", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}]}], "+", 
    RowBox[{"8", " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None], "-", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None]}], "+", 
    RowBox[{"8", " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None], "+", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"j", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "+", 
    RowBox[{"5", " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "+", 
    RowBox[{"5", " ", "j", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["j", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       RowBox[{"j", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8113238335158663`*^9, 3.890974354437698*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"eaafc6c5-8e4c-452f-a80b-7a7f9ab4b962"]
}, Open  ]],

Cell[TextData[{
 "Now we can calculate the series for Cos",
 StyleBox[" j",
  FontSlant->"Italic"],
 "[\[Theta]-\[Theta]']."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7fa18662-6cc4-40df-92a6-ca5babb4a692"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cjdth", "=", 
  RowBox[{"TrigReduce", "[", 
   RowBox[{"Truncate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cjth", "*", "cjthp"}], "+", 
      RowBox[{"sjth", "*", "sjthp"}]}], ",", "2"}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[37]:=",ExpressionUUID->"d50eb15b-e16f-4b97-99b1-f2968c7cd3ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{"j", " ", "\[Lambda]"}], "-", 
    RowBox[{"j", " ", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}]}], "]"}], "-", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["5", "8"], " ", 
   SuperscriptBox["e", "2"], " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{"e", " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["5", "8"], " ", 
   SuperscriptBox["e", "2"], " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{"e", " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{"j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["5", "8"], " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["5", "8"], " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323833825014*^9, 3.890974354672641*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"16f14bca-df71-445c-9034-e7257e2f081f"]
}, Open  ]],

Cell["Tidy up the terms (see Eq.(6.90)).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0f47df54-9a24-46bd-bf3d-038ae9235f06"],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e]", "Input",
 CellLabel->"In[38]:=",ExpressionUUID->"977b7b56-0928-4132-8599-e6406a519098"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{
    RowBox[{"j", " ", "\[Lambda]"}], "-", 
    RowBox[{"j", " ", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}]}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["j", "2"]}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["5", "8"], " ", "j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["5", "8"], " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["5", "8"], " ", "j", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "-", 
     RowBox[{"j", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{
      SuperscriptBox["j", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "+", 
        RowBox[{"j", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323833832199*^9, 3.8909743547253513`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"51e33d44-73b4-46e9-93ea-044aeeb24867"]
}, Open  ]],

Cell["Now we derive a high-order series for r/a (see Eq.(2.80)).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ad8caca5-31ff-4cfd-8881-132be977c4a6"],

Cell["\<\
troa = 
Expand[1+e^2/2-2e*
Series[
Sum[(1/s^2)*
D[BesselJ[s, s e],e]Cos[s*M],{s,1,6}],{e,0,6}]];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[39]:=",ExpressionUUID->"cd278562-0143-4db0-8409-17baa3c1059a"],

Cell["Tidy it up ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8332b962-1581-4df5-92db-cda318583845"],

Cell[CellGroupData[{

Cell["Collect[Expand[troa],e]", "Input",
 CellLabel->"In[40]:=",ExpressionUUID->"4e01c90f-c1d1-40aa-af98-6e1540529b1c"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", "M", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["3", "8"], " ", 
   SuperscriptBox["e", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", "M", "]"}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", "M"}], "]"}]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "6"]}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"4", " ", "M"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["e", "7"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"7", " ", 
        RowBox[{"Cos", "[", "M", "]"}]}], "18432"]}], "+", 
     FractionBox[
      RowBox[{"567", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"3", " ", "M"}], "]"}]}], "10240"], "-", 
     FractionBox[
      RowBox[{"4375", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"5", " ", "M"}], "]"}]}], "18432"]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["e", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"5", " ", 
       RowBox[{"Cos", "[", "M", "]"}]}], "384"], "-", 
     RowBox[{
      FractionBox["45", "256"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["125", "768"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"5", " ", "M"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["e", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "5"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"4", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["27", "160"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"6", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323833890181*^9, 3.89097435475415*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"d40438b7-05da-405d-be21-65e0f2ccf374"]
}, Open  ]],

Cell["... and truncate it to second order.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"184d77e7-2167-4035-ab9b-6aae863308cc"],

Cell[CellGroupData[{

Cell["roa = Collect[Expand[Series[Normal[troa],{e,0,2}]], e]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[41]:=",ExpressionUUID->"b4499d14-8085-4899-9fff-f3572ed3f450"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", "M", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323833943439*^9, 3.890974354772059*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"336ccfef-4169-4f82-bda8-42d8864d4e76"]
}, Open  ]],

Cell["Subtract 1 to get the series for \[CurlyEpsilon] (see Eq.(6.91)).", \
"Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fced62d0-28e0-4a20-9f24-5803deadf2e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyEpsilon]", "=", 
  RowBox[{
   RowBox[{"roa", "-", "1"}], " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{"M", "\[Rule]", 
     RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}]}], "}"}]}]}]], "Input",
 CellLabel->"In[42]:=",ExpressionUUID->"1f7d061e-6182-4fcb-aa3f-7cf4a5210865"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "e"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], ")"}]}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323833948914*^9, 3.890974354779501*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"058dbd5c-d495-4abc-9712-72465d2b33d6"]
}, Open  ]],

Cell["Derive the series for \[CurlyEpsilon]' by substitution.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"71cbb7ec-35b0-4155-aa29-4cb2cd024fa2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CurlyEpsilon]", "'"}], "=", " ", 
  RowBox[{"\[CurlyEpsilon]", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e", "\[Rule]", 
      RowBox[{"e", "'"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"\[Lambda]", "'"}]}], ",", 
     RowBox[{"\[CurlyPi]", "\[Rule]", 
      RowBox[{"\[CurlyPi]", "'"}]}]}], "}"}]}]}]], "Input",
 CellLabel->"In[43]:=",ExpressionUUID->"4e0cbb12-5e71-4828-bb41-81050adbc613"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Cos", "[", 
     RowBox[{
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None], "-", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}], "]"}]}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Lambda]", "\[Prime]",
           MultilineFunction->None], "-", 
          SuperscriptBox["\[CurlyPi]", "\[Prime]",
           MultilineFunction->None]}], ")"}]}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323834000778*^9, 3.890974354797064*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"554f605b-8e23-4ca4-8411-a18f8730b535"]
}, Open  ]],

Cell[TextData[{
 "Now we are in a position to put all this together to derive an expression \
for the direct part of the disturbing function to second order.  Here we make \
use of Eqs.(6.94)\[Dash](6.100).  The ",
 StyleBox["b",
  FontSlant->"Italic"],
 "[",
 StyleBox["s",
  FontSlant->"Italic"],
 ",",
 StyleBox["j",
  FontSlant->"Italic"],
 ",\[Alpha],",
 StyleBox["n",
  FontSlant->"Italic"],
 "] are Laplace coefficients."
}], "Text",ExpressionUUID->"18e1001a-1172-418f-8519-4c7d303ae70c"],

Cell["\<\
RD=
(
(1/2)*
(b[1/2,j,\[Alpha],0]+
\[CurlyEpsilon]*\[Alpha]*b[1/2,j,\[Alpha],1]+
\[CurlyEpsilon]'*(-\[Alpha]*b[1/2,j,\[Alpha],1]-b[1/2,j,\[Alpha],0])+
(1/2)*\[CurlyEpsilon]^2*\[Alpha]^2*b[1/2,j,\[Alpha],2]+
\[CurlyEpsilon]*\[CurlyEpsilon]'*(-\[Alpha]^2*b[1/2,j,\[Alpha],2]-2*\[Alpha]*\
b[1/2,j,\[Alpha],1])+
(1/2)*(\[CurlyEpsilon]')^2*
(\[Alpha]^2*b[1/2,j,\[Alpha],2]+4*\[Alpha]*b[1/2,j,\[Alpha],1]+2*b[1/2,j,\
\[Alpha],0])
)+
rapsi2*\[Alpha]*b[3/2,j,\[Alpha],0])*cjdth;\
\>", "Input",
 CellLabel->"In[44]:=",ExpressionUUID->"caccbe18-49f8-4890-9c88-799ebbaed8e8"],

Cell["Truncate and simplify this expression. ", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.811324044627633*^9, 3.81132404533569*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"72f8de5b-44c1-4bc2-b1b0-48b1cec9e8ad"],

Cell["RD=TrigReduce[Truncate[RD,2]];", "Input",
 CellLabel->"In[45]:=",ExpressionUUID->"935c2c85-8a7e-4c43-8619-060e229501f3"],

Cell[TextData[{
 "Expand the resulting expression for ",
 StyleBox["RD", "Input"],
 " (see Eqs.(6.102)",
 StyleBox["\[Dash](6.104)).",
  FontSize->11],
 "  The remaining work (not shown) consists of identifying and gathering \
terms in the same argument, using simple substitution if necessary.  This is \
described in the text."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0ff71ea2-c56c-4717-8acf-0889575d628e"],

Cell[CellGroupData[{

Cell["Expand[RD]", "Input",
 CellLabel->"In[46]:=",ExpressionUUID->"884c01dc-c788-45f8-a814-93a18eee18a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["5", "16"], " ", 
   SuperscriptBox["e", "2"], " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "j", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["s", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["s", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["5", "16"], " ", 
   SuperscriptBox["e", "2"], " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "j", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SuperscriptBox["e", "2"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["s", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["s", "2"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", "j", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", "e", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", "j", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", "e", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", "e", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "e", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", "e", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["9", "16"], " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["3", "8"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "j", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["9", "16"], " ", "j", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["j", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["3", "8"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "j", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "1"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "j", ",", "\[Alpha]", ",", "2"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "s", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "s", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "s", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "s", " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[Alpha]", " ", 
   RowBox[{"b", "[", 
    RowBox[{
     FractionBox["3", "2"], ",", "j", ",", "\[Alpha]", ",", "0"}], "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"j", " ", "\[Lambda]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     RowBox[{"j", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323835514893*^9, 3.890974356726935*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"4ce1c9c4-82fd-4305-8dbe-df92aaf049df"]
}, Open  ]],

Cell[TextData[{
 "For the indireact parts we need a series for ",
 StyleBox["r",
  FontSlant->"Italic"],
 "/",
 StyleBox["a",
  FontSlant->"Italic"],
 " in terms of longitudes (see Eq.(6.108))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4bfaea97-d21f-412c-b42f-a72e828fcebd"],

Cell[CellGroupData[{

Cell["roat=roa /. {M->\[Lambda]-\[CurlyPi]}", "Input",
 CellLabel->"In[47]:=",ExpressionUUID->"53646b55-a5ff-41b9-9713-01f092215e8b"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], ")"}]}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323835523389*^9, 3.890974356764038*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"a6add7e3-2f07-4fb9-87bc-4e03dceec36a"]
}, Open  ]],

Cell[TextData[{
 "We also need a series for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "'"}], "/", 
      RowBox[{"r", "'"}]}], ")"}], "2"], TraditionalForm]],ExpressionUUID->
  "1c6ddfe9-4dd3-4467-a1c5-cebbc4972ecc"],
 " and so we invert the series for ",
 StyleBox["r",
  FontSlant->"Italic"],
 "/",
 StyleBox["a",
  FontSlant->"Italic"],
 " square it",
 " and substitute (see Eq.(6.109))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"804bcd0f-5900-4781-8146-d7429b29a9cf"],

Cell[CellGroupData[{

Cell["\<\
aorp2=TrigReduce[Normal[Series[(1/roat)^2,{e,0,2}]]] /. {e->e',\[Lambda]->\
\[Lambda]',\[CurlyPi]->\[CurlyPi]'}\
\>", "Input",
 CellLabel->"In[48]:=",ExpressionUUID->"5c476cf0-1dcc-4633-bdcc-da3a13dd6d93"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    RowBox[{"4", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None], "-", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None], ")"}], "2"], "+", 
    RowBox[{"5", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.811323835571607*^9, 3.890974356785646*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"6f86afd1-336b-41c1-823f-3912854b2b3c"]
}, Open  ]],

Cell[TextData[{
 "Gather the terms in ",
 StyleBox["e",
  FontSlant->"Italic"],
 "' for comparison with Eq.(6.109)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"89a5f5e6-1892-43b5-bd9d-674383066b13"],

Cell[CellGroupData[{

Cell["Collect[Expand[%],e']", "Input",
 CellLabel->"In[49]:=",ExpressionUUID->"94c6acd8-d8c0-442f-905a-393a7615ca5d"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "+", 
     RowBox[{
      FractionBox["5", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.811323835577094*^9, 3.890974356793528*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"c4626abe-92d2-451b-b9c9-7c858cd7ca42"]
}, Open  ]],

Cell["\<\
Put all these together to get the expression for the indirect part with an \
external perturber (see Eq.(6.110)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"028b8acf-0039-4532-a891-c211df7288ba"],

Cell[CellGroupData[{

Cell["RE=Truncate[-roat*aorp2*cpsi,2]", "Input",
 CellLabel->"In[50]:=",ExpressionUUID->"4703050e-b852-465e-8a50-95b7cee194d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["s", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["s", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{"8", " ", "e", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"24", " ", "e", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[CurlyPi]", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "-", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "-", 
     RowBox[{"27", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "+", 
     RowBox[{"16", " ", "s", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["s", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"16", " ", "s", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "+", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["s", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["s", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CapitalOmega]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["s", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323835764584*^9, 3.890974356961534*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"fb9a91ff-f036-4c38-a2d9-c135df8c3ca8"]
}, Open  ]],

Cell["Re-arrange to gather the zeroth-order arguments.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7a3b76d1-adf3-4bfe-ae78-33a8c00f60c9"],

Cell[CellGroupData[{

Cell["Collect[RE,Cos[\[Lambda]-\[Lambda]']]", "Input",
 CellLabel->"In[51]:=",ExpressionUUID->"65c4a4e9-1964-4af0-bae3-f2bf7d0d8d2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["3", "8"]}], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"3", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"3", " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPi]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["27", "8"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox[
      SuperscriptBox["e", "2"], "2"], "+", 
     SuperscriptBox["s", "2"], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["s", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323835770653*^9, 3.890974356972337*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"2b06cb63-805a-447c-a029-d66ccb738769"]
}, Open  ]],

Cell[TextData[{
 "Make substitutions to get series for ",
 StyleBox["r",
  FontSlant->"Italic"],
 "'/",
 StyleBox["a",
  FontSlant->"Italic"],
 "' and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"a", "/", "r"}], ")"}], "2"], TraditionalForm]],ExpressionUUID->
  "36a0e613-c154-472c-8e82-63c95c84ad6c"],
 "(see Eq.(6.111))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d81b769a-4954-43a9-99e2-45097a96532d"],

Cell["\<\
roatp=roat /. {e->e',\[Lambda]->\[Lambda]',\[CurlyPi]->\[CurlyPi]'};
aor2=aorp2 /. {e'->e,\[Lambda]'->\[Lambda],\[CurlyPi]'->\[CurlyPi]};\
\>", "Input",
 CellLabel->"In[52]:=",ExpressionUUID->"42f20a1e-2c14-4590-8ede-1158557d70af"],

Cell["\<\
Finally we get the series for the indirect part due to an internal perturber \
(see Eq.(6.111)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9530b70d-6e34-4a70-a467-df873c9d8084"],

Cell[CellGroupData[{

Cell["RI=Truncate[-roatp*aor2*cpsi,2]", "Input",
 CellLabel->"In[54]:=",ExpressionUUID->"17381099-8ca4-41f9-8346-c630125cc322"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"2", " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["s", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{"27", " ", 
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["s", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}]}], "+", 
     RowBox[{"24", " ", "e", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"8", " ", "e", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        SuperscriptBox["\[CurlyPi]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "-", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CurlyPi]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "+", 
     RowBox[{"16", " ", "s", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["s", "\[Prime]",
       MultilineFunction->None]}], "-", 
     RowBox[{"16", " ", "s", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "+", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["s", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "-", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["s", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}], "-", 
     RowBox[{"8", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CapitalOmega]", "\[Prime]",
          MultilineFunction->None]}]}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["s", "\[Prime]",
         MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323835921399*^9, 3.8909743571337423`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"70770261-3ab6-4a8a-bb98-4fec08b6a5fc"]
}, Open  ]],

Cell["Re-arrange to gather the zeroth-order arguments.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c95b2f3c-306e-4d03-8827-ff9cecc1bdcb"],

Cell["Collect[RI,Cos[\[Lambda]-\[Lambda]']]", "Input",
 CellLabel->"In[55]:=",ExpressionUUID->"d035106b-9fc7-4f20-b728-794e413d7564"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["27", "8"]}], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"3", " ", "\[Lambda]"}], "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{"2", " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CurlyPi]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["s", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", "\[CapitalOmega]"}], "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "+", 
  RowBox[{"3", " ", "e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"e", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", "\[Lambda]"}], "-", "\[CurlyPi]", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     SuperscriptBox["\[CurlyPi]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["e", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "-", 
  RowBox[{
   FractionBox["3", "8"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Lambda]", "\[Prime]",
       MultilineFunction->None]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["e", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{"2", " ", "s", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", "\[CapitalOmega]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "+", 
     SuperscriptBox["\[CapitalOmega]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   SuperscriptBox["s", "\[Prime]",
    MultilineFunction->None]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "+", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None], ")"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Lambda]", "-", 
     SuperscriptBox["\[Lambda]", "\[Prime]",
      MultilineFunction->None]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox[
      SuperscriptBox["e", "2"], "2"], "+", 
     SuperscriptBox["s", "2"], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None], ")"}], "2"], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["s", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.811323835927697*^9, 3.890974357143523*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"c7050cd3-94d5-45d9-9247-b231ff9094e0"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1012, 661},
WindowMargins->{{82, Automatic}, {Automatic, 26}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"fcc07126-2369-4215-97ea-62f8f58ec42f"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"268cac08-3ca0-4a0b-abd5-463465f5e3c7"],
Cell[1000, 31, 96, 0, 67, "Section",ExpressionUUID->"577fd798-653f-4a35-8939-48e844b36cf6"],
Cell[1099, 33, 450, 10, 95, "Text",ExpressionUUID->"977a8fa1-c91b-4c38-ae3e-967ab3028233"],
Cell[1552, 45, 290, 7, 66, "Input",ExpressionUUID->"f62bc1f8-aefc-4adb-9267-62d9e50800f8"],
Cell[1845, 54, 264, 8, 53, "Text",ExpressionUUID->"c9d90c32-eaae-4c7e-add1-e055739650ce"],
Cell[CellGroupData[{
Cell[2134, 66, 280, 8, 102, "Input",ExpressionUUID->"a677e534-7836-4fc2-944c-dfc5fd987d59"],
Cell[2417, 76, 610, 18, 50, "Output",ExpressionUUID->"98784b29-267a-4b26-960c-76246819e6f2"]
}, Open  ]],
Cell[3042, 97, 271, 8, 53, "Text",ExpressionUUID->"b3eb6b3e-3e99-40fa-a481-c9b6ca135bb6"],
Cell[CellGroupData[{
Cell[3338, 109, 115, 1, 30, "Input",ExpressionUUID->"5754e5fd-9111-420a-ad4c-b5f05020ed1f"],
Cell[3456, 112, 633, 19, 51, "Output",ExpressionUUID->"3fe99f9c-1176-4b0c-a017-eccf07bb6825"]
}, Open  ]],
Cell[4104, 134, 238, 8, 53, "Text",ExpressionUUID->"ac8537ed-97ad-44ac-bdec-022c311d3934"],
Cell[CellGroupData[{
Cell[4367, 146, 256, 8, 102, "Input",ExpressionUUID->"ff7854cf-b953-470f-821e-d148f793270a"],
Cell[4626, 156, 607, 18, 50, "Output",ExpressionUUID->"ebfe3eb6-9408-42fb-b195-6c88aeafa011"]
}, Open  ]],
Cell[5248, 177, 271, 8, 53, "Text",ExpressionUUID->"626cffce-a6e4-4de1-bc46-040ba6ffd55f"],
Cell[CellGroupData[{
Cell[5544, 189, 115, 1, 30, "Input",ExpressionUUID->"24d75f50-ebd6-4d28-ad47-341b56794b16"],
Cell[5662, 192, 707, 22, 50, "Output",ExpressionUUID->"52591f76-e150-4f7e-88b4-e62ddd681291"]
}, Open  ]],
Cell[6384, 217, 289, 11, 53, "Text",ExpressionUUID->"fb4bbca1-f3f9-46c8-8065-25628f6ab695"],
Cell[6676, 230, 150, 2, 30, "Input",ExpressionUUID->"012207de-bb62-4072-8bfc-71c191b394f8"],
Cell[6829, 234, 150, 2, 30, "Input",ExpressionUUID->"76740d3a-2c83-4d1d-b974-d322548a2c70"],
Cell[6982, 238, 463, 20, 53, "Text",ExpressionUUID->"ff5d6f2d-6f7b-4af7-8bb7-bc88f1195034"],
Cell[CellGroupData[{
Cell[7470, 262, 188, 2, 30, "Input",ExpressionUUID->"5215fb4d-5f52-434f-b2d3-f08654290073"],
Cell[7661, 266, 1033, 32, 50, "Output",ExpressionUUID->"370b92e1-c126-40a6-824b-b32cd5acefc7"]
}, Open  ]],
Cell[8709, 301, 171, 2, 30, "Input",ExpressionUUID->"5a218f99-cc40-416a-96bb-8eac8b47a6b3"],
Cell[CellGroupData[{
Cell[8905, 307, 189, 2, 30, "Input",ExpressionUUID->"6d40ce15-76e1-4123-8dac-256335df00bb"],
Cell[9097, 311, 1013, 31, 50, "Output",ExpressionUUID->"30d55bbe-e643-4614-b64c-defd74ff600d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10147, 347, 116, 1, 30, "Input",ExpressionUUID->"3fc990f7-73e2-46b0-a405-0710aff369bc"],
Cell[10266, 350, 941, 29, 50, "Output",ExpressionUUID->"41149c03-d5d3-46f2-83a0-77d81e1b7629"]
}, Open  ]],
Cell[11222, 382, 172, 2, 30, "Input",ExpressionUUID->"14c910b9-02ad-4fc1-9454-69bb0fd0ae25"],
Cell[11397, 386, 349, 16, 53, "Text",ExpressionUUID->"ae292da0-7984-4925-b141-782653f3a7fd"],
Cell[11749, 404, 307, 9, 52, "Input",ExpressionUUID->"eeefe81d-aba8-4b60-8137-a63d7d65b076"],
Cell[12059, 415, 239, 8, 53, "Text",ExpressionUUID->"356a18af-bc1e-4812-a8ea-b373fc49bcb2"],
Cell[CellGroupData[{
Cell[12323, 427, 539, 14, 52, "Input",ExpressionUUID->"d2a41ff3-7c4d-44bd-9eee-f6ed8e120799"],
Cell[12865, 443, 1432, 41, 73, "Output",ExpressionUUID->"0c1e9c21-659a-4175-9bdf-fd1984beb71b"]
}, Open  ]],
Cell[14312, 487, 215, 8, 53, "Text",ExpressionUUID->"d2e7f5ee-0410-4a15-87e6-ea58a23cb951"],
Cell[CellGroupData[{
Cell[14552, 499, 539, 14, 52, "Input",ExpressionUUID->"b278f798-0b27-494a-bc10-96cfe5da416c"],
Cell[15094, 515, 1430, 41, 73, "Output",ExpressionUUID->"12d2cec3-32be-45ed-88a6-a12b5000aa0d"]
}, Open  ]],
Cell[16539, 559, 154, 3, 53, "Text",ExpressionUUID->"8f8b3f99-284d-4dac-897e-4d6cdd030069"],
Cell[CellGroupData[{
Cell[16718, 566, 361, 9, 52, "Input",ExpressionUUID->"3143bde6-6c63-405b-8bee-c8ba00932f78"],
Cell[17082, 577, 593, 17, 34, "Output",ExpressionUUID->"4b068232-5ee9-4059-9380-cd3f6b3be37a"]
}, Open  ]],
Cell[17690, 597, 322, 14, 53, "Text",ExpressionUUID->"28480724-eb2a-4fdc-a598-0fa5f2b655a5"],
Cell[18015, 613, 589, 16, 30, "Input",ExpressionUUID->"8005ec93-998c-42ec-977b-3edb923f1df0"],
Cell[18607, 631, 589, 16, 30, "Input",ExpressionUUID->"aff55732-11ec-4325-99ea-8c02b131dede"],
Cell[19199, 649, 589, 16, 30, "Input",ExpressionUUID->"53a59654-c56c-4a32-bb45-d8819f15aafa"],
Cell[19791, 667, 205, 5, 53, "Text",ExpressionUUID->"41f17a8f-ae14-40e3-9f7e-4777ea545792"],
Cell[CellGroupData[{
Cell[20021, 676, 953, 26, 30, "Input",ExpressionUUID->"0d648b35-5eec-4dd5-abd0-bfbcc88199f3"],
Cell[20977, 704, 6350, 182, 167, "Output",ExpressionUUID->"aadb0f41-88c5-4905-8cfe-414bfd350e57"]
}, Open  ]],
Cell[27342, 889, 224, 6, 53, "Text",ExpressionUUID->"cb171c94-3a59-4560-b0c0-f8353607f080"],
Cell[CellGroupData[{
Cell[27591, 899, 126, 1, 30, "Input",ExpressionUUID->"1b7d8f61-a6b2-45ba-aab6-de9af2f6115b"],
Cell[27720, 902, 6239, 174, 133, "Output",ExpressionUUID->"70a14408-f066-4338-9682-6dce50bc4044"]
}, Open  ]],
Cell[33974, 1079, 316, 9, 53, "Text",ExpressionUUID->"5a770892-14df-4b80-8063-90f534c6d2ed"],
Cell[34293, 1090, 557, 12, 102, "Input",ExpressionUUID->"ee6e06a7-2f28-45ce-be47-3af8c8d59dd4"],
Cell[34853, 1104, 267, 6, 53, "Text",ExpressionUUID->"bf5ff0df-1bbc-4872-82a0-1fb42f6f1867"],
Cell[CellGroupData[{
Cell[35145, 1114, 210, 4, 30, "Input",ExpressionUUID->"4c0fe377-b9da-4d37-81a1-06ab1b60449d"],
Cell[35358, 1120, 2050, 56, 34, "Output",ExpressionUUID->"0ccc12cd-95db-4641-9559-b84d54fa2c63"]
}, Open  ]],
Cell[37423, 1179, 351, 12, 53, "Text",ExpressionUUID->"ceb1e302-fe67-45a2-a0e8-a3d985e99a8e"],
Cell[CellGroupData[{
Cell[37799, 1195, 202, 4, 30, "Input",ExpressionUUID->"533a25db-f3a7-427e-bab8-35cc0b4f712d"],
Cell[38004, 1201, 2158, 60, 87, "Output",ExpressionUUID->"d5d4726a-f01c-4a34-b112-94fa01fdbcf2"]
}, Open  ]],
Cell[40177, 1264, 407, 12, 76, "Text",ExpressionUUID->"7e9cd7f6-ad7c-4bec-8298-08860d88fae7"],
Cell[CellGroupData[{
Cell[40609, 1280, 266, 9, 120, "Input",ExpressionUUID->"0b616fb9-f808-42ee-bc88-e7a4f401444f"],
Cell[40878, 1291, 1460, 48, 91, "Output",ExpressionUUID->"7ae383b1-488d-4c19-9903-b24c0eb04838"]
}, Open  ]],
Cell[42353, 1342, 247, 8, 53, "Text",ExpressionUUID->"7e2b9cf9-8a9b-4d00-b8d8-bc04fec96542"],
Cell[42603, 1352, 214, 6, 66, "Input",ExpressionUUID->"6495a172-97b8-4e25-b412-bbfe0085836b"],
Cell[42820, 1360, 312, 11, 53, "Text",ExpressionUUID->"b2b87128-93c2-4034-a19d-e902f2289b3e"],
Cell[CellGroupData[{
Cell[43157, 1375, 322, 9, 30, "Input",ExpressionUUID->"7dd33d17-123e-4ab7-9f27-6e3a77852b3d"],
Cell[43482, 1386, 407, 10, 49, "Output",ExpressionUUID->"1d73e94c-1500-4ff0-ad4b-8ca8989a6f2e"]
}, Open  ]],
Cell[43904, 1399, 169, 3, 53, "Text",ExpressionUUID->"b47efd75-3e86-4df0-af8d-ecc455c98443"],
Cell[CellGroupData[{
Cell[44098, 1406, 759, 20, 30, "Input",ExpressionUUID->"6f5ef7c1-6089-4c90-a28a-03ac74b66ad6"],
Cell[44860, 1428, 527, 14, 49, "Output",ExpressionUUID->"c4e080bf-d185-4040-abe1-22007be1edfb"]
}, Open  ]],
Cell[45402, 1445, 230, 8, 53, "Text",ExpressionUUID->"8bbf8057-5d5a-464b-b093-7a16ba7b2f11"],
Cell[CellGroupData[{
Cell[45657, 1457, 401, 11, 30, "Input",ExpressionUUID->"8434f3ac-d5c3-498f-afaa-15ea71e381b3"],
Cell[46061, 1470, 1979, 53, 75, "Output",ExpressionUUID->"68942aa9-5883-4f0e-99e7-ea86ebbe2f42"]
}, Open  ]],
Cell[48055, 1526, 168, 3, 53, "Text",ExpressionUUID->"d0322ef1-2d6f-4594-a398-574802936545"],
Cell[CellGroupData[{
Cell[48248, 1533, 116, 1, 30, "Input",ExpressionUUID->"06a7b71c-e641-44a6-91bd-cedaef77b8a9"],
Cell[48367, 1536, 1980, 57, 73, "Output",ExpressionUUID->"b9081d0b-62a0-4ab7-b378-11b48fe01c29"]
}, Open  ]],
Cell[50362, 1596, 261, 8, 53, "Text",ExpressionUUID->"53a03c90-7dd0-4027-a746-e5f6495dc747"],
Cell[CellGroupData[{
Cell[50648, 1608, 401, 11, 30, "Input",ExpressionUUID->"bcbfd89e-e400-404a-9746-1689c3f6398c"],
Cell[51052, 1621, 1981, 53, 75, "Output",ExpressionUUID->"da331f73-5b85-42ae-b182-ac152a485ef7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53070, 1679, 116, 1, 30, "Input",ExpressionUUID->"76786cea-eff7-4360-a50b-42669a6a1c24"],
Cell[53189, 1682, 1958, 56, 73, "Output",ExpressionUUID->"a3032a31-618f-4cf2-85c2-658d5322b843"]
}, Open  ]],
Cell[55162, 1741, 238, 8, 53, "Text",ExpressionUUID->"f5ac6518-87f5-42f1-bec6-11ab85058858"],
Cell[CellGroupData[{
Cell[55425, 1753, 580, 15, 30, "Input",ExpressionUUID->"ce84ea48-b854-45ab-8766-43361e3c2bae"],
Cell[56008, 1770, 3993, 111, 75, "Output",ExpressionUUID->"b54be3f6-e081-4766-8949-dbcc0560c8c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60038, 1886, 121, 1, 30, "Input",ExpressionUUID->"b9532fd9-78e7-4dde-a507-d6960c7242d5"],
Cell[60162, 1889, 3564, 101, 73, "Output",ExpressionUUID->"c05435eb-fd56-42d4-8158-9bb3b9c9502c"]
}, Open  ]],
Cell[63741, 1993, 238, 8, 53, "Text",ExpressionUUID->"998827ba-7f74-4cd7-9195-b641b2228e90"],
Cell[CellGroupData[{
Cell[64004, 2005, 580, 15, 30, "Input",ExpressionUUID->"74991f30-b8d7-4ffd-bf34-d5ee39e05362"],
Cell[64587, 2022, 3995, 111, 75, "Output",ExpressionUUID->"eaafc6c5-8e4c-452f-a80b-7a7f9ab4b962"]
}, Open  ]],
Cell[68597, 2136, 246, 8, 53, "Text",ExpressionUUID->"7fa18662-6cc4-40df-92a6-ca5babb4a692"],
Cell[CellGroupData[{
Cell[68868, 2148, 324, 8, 30, "Input",ExpressionUUID->"d50eb15b-e16f-4b97-99b1-f2968c7cd3ed"],
Cell[69195, 2158, 8664, 246, 209, "Output",ExpressionUUID->"16f14bca-df71-445c-9034-e7257e2f081f"]
}, Open  ]],
Cell[77874, 2407, 160, 3, 53, "Text",ExpressionUUID->"0f47df54-9a24-46bd-bf3d-038ae9235f06"],
Cell[CellGroupData[{
Cell[78059, 2414, 116, 1, 30, "Input",ExpressionUUID->"977b7b56-0928-4132-8599-e6406a519098"],
Cell[78178, 2417, 8963, 249, 215, "Output",ExpressionUUID->"51e33d44-73b4-46e9-93ea-044aeeb24867"]
}, Open  ]],
Cell[87156, 2669, 184, 3, 53, "Text",ExpressionUUID->"ad8caca5-31ff-4cfd-8881-132be977c4a6"],
Cell[87343, 2674, 232, 8, 102, "Input",ExpressionUUID->"cd278562-0143-4db0-8409-17baa3c1059a"],
Cell[87578, 2684, 140, 3, 53, "Text",ExpressionUUID->"8332b962-1581-4df5-92db-cda318583845"],
Cell[CellGroupData[{
Cell[87743, 2691, 119, 1, 30, "Input",ExpressionUUID->"4e01c90f-c1d1-40aa-af98-6e1540529b1c"],
Cell[87865, 2694, 2490, 82, 128, "Output",ExpressionUUID->"d40438b7-05da-405d-be21-65e0f2ccf374"]
}, Open  ]],
Cell[90370, 2779, 162, 3, 53, "Text",ExpressionUUID->"184d77e7-2167-4035-ab9b-6aae863308cc"],
Cell[CellGroupData[{
Cell[90557, 2786, 182, 2, 30, "Input",ExpressionUUID->"b4499d14-8085-4899-9fff-f3572ed3f450"],
Cell[90742, 2790, 491, 14, 49, "Output",ExpressionUUID->"336ccfef-4169-4f82-bda8-42d8864d4e76"]
}, Open  ]],
Cell[91248, 2807, 193, 4, 53, "Text",ExpressionUUID->"fced62d0-28e0-4a20-9f24-5803deadf2e7"],
Cell[CellGroupData[{
Cell[91466, 2815, 300, 7, 30, "Input",ExpressionUUID->"1f7d061e-6182-4fcb-aa3f-7cf4a5210865"],
Cell[91769, 2824, 623, 19, 49, "Output",ExpressionUUID->"058dbd5c-d495-4abc-9712-72465d2b33d6"]
}, Open  ]],
Cell[92407, 2846, 181, 3, 53, "Text",ExpressionUUID->"71cbb7ec-35b0-4155-aa29-4cb2cd024fa2"],
Cell[CellGroupData[{
Cell[92613, 2853, 468, 12, 30, "Input",ExpressionUUID->"4e0cbb12-5e71-4828-bb41-81050adbc613"],
Cell[93084, 2867, 1055, 31, 49, "Output",ExpressionUUID->"554f605b-8e23-4ca4-8411-a18f8730b535"]
}, Open  ]],
Cell[94154, 2901, 495, 16, 58, "Text",ExpressionUUID->"18e1001a-1172-418f-8519-4c7d303ae70c"],
Cell[94652, 2919, 574, 16, 228, "Input",ExpressionUUID->"caccbe18-49f8-4890-9c88-799ebbaed8e8"],
Cell[95229, 2937, 230, 4, 53, "Text",ExpressionUUID->"72f8de5b-44c1-4bc2-b1b0-48b1cec9e8ad"],
Cell[95462, 2943, 126, 1, 30, "Input",ExpressionUUID->"935c2c85-8a7e-4c43-8619-060e229501f3"],
Cell[95591, 2946, 451, 12, 76, "Text",ExpressionUUID->"0ff71ea2-c56c-4717-8acf-0889575d628e"],
Cell[CellGroupData[{
Cell[96067, 2962, 106, 1, 30, "Input",ExpressionUUID->"884c01dc-c788-45f8-a814-93a18eee18a0"],
Cell[96176, 2965, 42188, 1159, 1282, "Output",ExpressionUUID->"4ce1c9c4-82fd-4305-8dbe-df92aaf049df"]
}, Open  ]],
Cell[138379, 4127, 316, 11, 53, "Text",ExpressionUUID->"4bfaea97-d21f-412c-b42f-a72e828fcebd"],
Cell[CellGroupData[{
Cell[138720, 4142, 133, 1, 30, "Input",ExpressionUUID->"53646b55-a5ff-41b9-9713-01f092215e8b"],
Cell[138856, 4145, 614, 18, 49, "Output",ExpressionUUID->"a6add7e3-2f07-4fb9-87bc-4e03dceec36a"]
}, Open  ]],
Cell[139485, 4166, 570, 21, 53, "Text",ExpressionUUID->"804bcd0f-5900-4781-8146-d7429b29a9cf"],
Cell[CellGroupData[{
Cell[140080, 4191, 215, 4, 30, "Input",ExpressionUUID->"5c476cf0-1dcc-4633-bdcc-da3a13dd6d93"],
Cell[140298, 4197, 1148, 32, 49, "Output",ExpressionUUID->"6f86afd1-336b-41c1-823f-3912854b2b3c"]
}, Open  ]],
Cell[141461, 4232, 238, 8, 53, "Text",ExpressionUUID->"89a5f5e6-1892-43b5-bd9d-674383066b13"],
Cell[CellGroupData[{
Cell[141724, 4244, 117, 1, 30, "Input",ExpressionUUID->"94c6acd8-d8c0-442f-905a-393a7615ca5d"],
Cell[141844, 4247, 1045, 30, 49, "Output",ExpressionUUID->"c4626abe-92d2-451b-b9c9-7c858cd7ca42"]
}, Open  ]],
Cell[142904, 4280, 247, 6, 53, "Text",ExpressionUUID->"028b8acf-0039-4532-a891-c211df7288ba"],
Cell[CellGroupData[{
Cell[143176, 4290, 127, 1, 30, "Input",ExpressionUUID->"4703050e-b852-465e-8a50-95b7cee194d8"],
Cell[143306, 4293, 6128, 163, 134, "Output",ExpressionUUID->"fb9a91ff-f036-4c38-a2d9-c135df8c3ca8"]
}, Open  ]],
Cell[149449, 4459, 174, 3, 53, "Text",ExpressionUUID->"7a3b76d1-adf3-4bfe-ae78-33a8c00f60c9"],
Cell[CellGroupData[{
Cell[149648, 4466, 133, 1, 30, "Input",ExpressionUUID->"65c4a4e9-1964-4af0-bae3-f2bf7d0d8d2c"],
Cell[149784, 4469, 5213, 149, 135, "Output",ExpressionUUID->"2b06cb63-805a-447c-a029-d66ccb738769"]
}, Open  ]],
Cell[155012, 4621, 480, 18, 53, "Text",ExpressionUUID->"d81b769a-4954-43a9-99e2-45097a96532d"],
Cell[155495, 4641, 241, 4, 48, "Input",ExpressionUUID->"42f20a1e-2c14-4590-8ede-1158557d70af"],
Cell[155739, 4647, 230, 6, 53, "Text",ExpressionUUID->"9530b70d-6e34-4a70-a467-df873c9d8084"],
Cell[CellGroupData[{
Cell[155994, 4657, 127, 1, 30, "Input",ExpressionUUID->"17381099-8ca4-41f9-8346-c630125cc322"],
Cell[156124, 4660, 6118, 163, 134, "Output",ExpressionUUID->"70770261-3ab6-4a8a-bb98-4fec08b6a5fc"]
}, Open  ]],
Cell[162257, 4826, 174, 3, 53, "Text",ExpressionUUID->"c95b2f3c-306e-4d03-8827-ff9cecc1bdcb"],
Cell[162434, 4831, 133, 1, 30, "Input",ExpressionUUID->"d035106b-9fc7-4f20-b728-794e413d7564"],
Cell[162570, 4834, 5207, 149, 135, "Output",ExpressionUUID->"c7050cd3-94d5-45d9-9247-b231ff9094e0"]
}
]
*)

